@@ -7,7 +7,6 @@ the feincms_ namespace.
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db import models
-from django.db.models import Max
 from django.template.loader import render_to_string
 from django.utils.encoding import force_unicode
 from django.utils.translation import ugettext_lazy as _
@@ -309,18 +308,18 @@ class Base(models.Model):
         """
         This is the method you'll use to create concrete content types.
 
-        If the CMS base class is `page.models.Page`, its database table will be
-        `page_page`. A concrete content type which is created from `ImageContent`
-        will use `page_page_imagecontent` as its table.
+        If the CMS base class is ``page.models.Page``, its database table will be
+        ``page_page``. A concrete content type which is created from ``ImageContent``
+        will use ``page_page_imagecontent`` as its table.
 
         If you want a content type only available in a subset of regions, you can
-        pass a list/tuple of region keys as `regions'. The content type will only
+        pass a list/tuple of region keys as ``regions``. The content type will only
         appear in the corresponding tabs in the item editor.
 
         You can pass additional keyword arguments to this factory function. These
         keyword arguments will be passed on to the concrete content type, provided
-        that it has a `initialize_type` classmethod. This is used f.e. in
-        `MediaFileContent` to pass a set of possible media positions (f.e. left,
+        that it has a ``initialize_type`` classmethod. This is used f.e. in
+        ``MediaFileContent`` to pass a set of possible media positions (f.e. left,
         right, centered) through to the content type.
         """
 
@@ -450,23 +449,6 @@ class Base(models.Model):
             cls.objects.filter(parent=self).delete()
         self.copy_content_from(obj)
 
-    def append_content_from(self, obj):
-        ordering = dict((region.key, -1) for region in self.template.regions)
-        # determine highest orderings for every content type
-        for cls in self._feincms_content_types:
-            values = cls.objects.filter(parent=self).values('region').annotate(Max('ordering'))
-            for dic in values:
-                ordering[dic['region']] = max(ordering[dic['region']], dic['ordering__max'])
-
-        for cls in self._feincms_content_types:
-            for content in cls.objects.filter(parent=obj):
-                new = copy_model_instance(content, exclude=('id', 'parent'))
-                # Adjust ordering value so that new contents will be appended
-                new.ordering += ordering[new.region] + 1
-                new.parent = self
-                new.save()
-
-
 
 class ContentProxy(object):
     """
