@@ -12,5 +12,5 @@ def register(cls, admin_cls):
     cls.add_to_class('meta_description', models.TextField(_('meta description'), blank=True,
         help_text=_('This will be prepended to the default description.')))
 
-    admin_cls.fieldsets[1][1]['fields'] += ('meta_keywords', 'meta_description')
-    admin_cls.search_fields += ('meta_keywords', 'meta_description')
+    admin_cls.fieldsets[1][1]['fields'].extend(['meta_keywords', 'meta_description'])
+    admin_cls.search_fields.extend(['meta_keywords', 'meta_description'])
